@@ -5,13 +5,12 @@ import hashlib
 import os
 import traceback
 import math
+import time
 
 from django.core.mail import send_mail
 from requests import ConnectionError
 import simplejson
-from gevent import socket
 import rawes
-import gevent
 from django.conf import settings
 
 from dimagi.utils.decorators.memoized import memoized
@@ -67,7 +66,7 @@ class autoretry_connection(object):
                         msg=str(e),
                         delay=next_delay
                     ))
-                    gevent.sleep(next_delay)
+                    time.sleep(next_delay)
                     current_tries += 1
                     if current_tries % MAX_RETRIES == 0:
                         pillow_logging.error("Pillowtop error, connectivity issues for %s. %s tries with %s second interval" % (fn.__name__, current_tries, RETRY_INTERVAL))
@@ -98,6 +97,7 @@ class BasicPillow(object):
     document_class = None  # couchdbkit Document class
     changes_seen = 0
     couch_db = None
+    include_docs = True
 
     def __init__(self, couch_db=None, document_class=None):
         if document_class:
@@ -117,7 +117,7 @@ class BasicPillow(object):
         http://couchdbkit.org/docs/changes.html
         """
         with ChangesStream(self.couch_db, feed='continuous', heartbeat=True, since=self.since,
-                           filter=self.couch_filter, include_docs=True, **self.extra_args) as st:
+                           filter=self.couch_filter, include_docs=self.include_docs, **self.extra_args) as st:
             for c in st:
                 self.processor(c)
 
@@ -285,6 +285,7 @@ class PythonPillow(BasicPillow):
         self.chunk_size = chunk_size
         self.use_chunking = chunk_size > 0
         self.checkpoint_frequency = checkpoint_frequency
+        self.include_docs = not self.use_chunking
         if self.document_class:
             if self.use_chunking:
                 self.couch_db = CachedCouchDB(self.document_class.get_db().uri, readonly=False)
@@ -310,16 +311,19 @@ class PythonPillow(BasicPillow):
                 except Exception:
                     logging.exception('something went wrong processing change %s (%s)' % (change['seq'], change['id']))
 
-
     def processor(self, change, do_set_checkpoint=True):
         self.changes_seen += 1
-        self.change_queue.append(change)
         if self.use_chunking:
+            self.change_queue.append(change)
             if len(self.change_queue) > self.chunk_size:
                 self.process_chunk()
-        else:
+        elif self.python_filter(change['doc']):
             self.process_change(change)
         if self.changes_seen % self.checkpoint_frequency == 0 and do_set_checkpoint:
+            # if using chunking make sure we never allow the checkpoint to get in
+            # front of the chunks
+            if self.use_chunking:
+                self.process_chunk()
             self.set_checkpoint(change)
 
     def run(self):
@@ -502,7 +506,7 @@ class ElasticPillow(BasicPillow):
                 current_tries += 1
                 pillow_logging.error("[%s] put_robust error %s attempt %d/%d" % (
                     self.get_name(), ex, current_tries, retries))
-                gevent.sleep(math.pow(RETRY_INTERVAL, current_tries))
+                time.sleep(math.pow(RETRY_INTERVAL, current_tries))
 
                 if current_tries == retries:
                     message = "[%s] Max retry error on %s" % (self.get_name(), path)
